==> cornsnake-0.0.34.tar.gz: cornsnake-0.0.34/README.md <==
# cornsnake

A small library wrapping common Python utilities for working with files, git, ZIP, lists, processes, dates and times.

Functions that I find myself writing time and again, on various OSS and personal projects - so collecting in one place, in case it is of use!

[url_repo]: https://github.com/mrseanryan/cornsnake
[url_semver_org]: https://semver.org/

[![MIT License][img_license]][url_license]
[![Supported Python Versions][img_pyversions]][url_pyversions]
[![cornsnake][img_version]][url_version]
[![PyPI Releases][img_pypi]][url_pypi]

[img_license]: https://img.shields.io/badge/License-MIT-blue.svg
[url_license]: https://github.com/mrseanryan/cornsnake/blob/master/LICENSE

[url_version]: https://pypi.org/project/cornsnake/

[img_version]: https://img.shields.io/static/v1.svg?label=SemVer&message=cornsnake&color=blue
[url_version]: https://pypi.org/project/bumpver/

[img_pypi]: https://img.shields.io/badge/PyPI-wheels-green.svg
[url_pypi]: https://pypi.org/project/cornsnake/#files

[img_pyversions]: https://img.shields.io/pypi/pyversions/cornsnake.svg
[url_pyversions]: https://pypi.python.org/pypi/cornsnake

## Install

```
python -m pip install --upgrade cornsnake
```

## Dependencies

- Python 3.11 or higher

```
pip install PyMuPDF
```

- fitz is for PDF parsing (installed as PyMuPDF)

## Usage

Functions are organised in logical groups like `util_file` or `util_print`.

To see what functions are available, see the [source code](https://github.com/mrseanryan/cornsnake/tree/master/src/cornsnake).

For an example, see the [e2e tests](https://github.com/mrseanryan/cornsnake/tree/master/e2e).

## References

- [github repo](https://github.com/mrseanryan/cornsnake)
- [pypi package](https://pypi.org/project/cornsnake/)

==> cornsnake-0.0.37.tar.gz: cornsnake-0.0.37/README.md <==
# cornsnake

A small library wrapping common Python utilities for working with files, git, ZIP, lists, processes, dates and times.

Functions that I find myself writing time and again, on various OSS and personal projects - so collecting in one place, in case it is of use!

[Documentation](http://docs.mrseanryan.cornsnake.s3-website-eu-west-1.amazonaws.com/)

[url_repo]: https://github.com/mrseanryan/cornsnake
[url_semver_org]: https://semver.org/

[![MIT License][img_license]][url_license]
[![Supported Python Versions][img_pyversions]][url_pyversions]
[![cornsnake][img_version]][url_version]

[![PyPI Releases][img_pypi]][url_pypi]
[![PyPI - Downloads](https://img.shields.io/pypi/dm/cornsnake.svg)](https://pypi.org/project/cornsnake)

[img_license]: https://img.shields.io/badge/License-MIT-blue.svg
[url_license]: https://github.com/mrseanryan/cornsnake/blob/master/LICENSE

[url_version]: https://pypi.org/project/cornsnake/

[img_version]: https://img.shields.io/static/v1.svg?label=SemVer&message=cornsnake&color=blue
[url_version]: https://pypi.org/project/bumpver/

[img_pypi]: https://img.shields.io/badge/PyPI-wheels-green.svg
[url_pypi]: https://pypi.org/project/cornsnake/#files

[img_pyversions]: https://img.shields.io/pypi/pyversions/cornsnake.svg
[url_pyversions]: https://pypi.python.org/pypi/cornsnake

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/K3K73ALBJ)

## Install

```
python -m pip install --upgrade cornsnake
```

## Dependencies

- Python 3.11 or higher

```
pip install PyMuPDF
```

- fitz is for PDF parsing (installed as PyMuPDF)

## Usage

Functions are organised in logical groups like `util_file` or `util_print`.

To see what functions are available, see the [source code](https://github.com/mrseanryan/cornsnake/tree/master/cornsnake).

For an example, see the [e2e tests](https://github.com/mrseanryan/cornsnake/tree/master/e2e).

## References

- [github repo](https://github.com/mrseanryan/cornsnake)
- [pypi package](https://pypi.org/project/cornsnake/)
